@@ -4,12 +4,7 @@ from .models import MailerMessage
 @task(name="tasks.send_mail")
 def send_mail(pk):
     message = MailerMessage.objects.get(pk=pk)
-    message.send_mail()
-
-#Cached Services
-@task()
-def send_mail(mailer):
-    mailer.send()
+    message._send()
 
 @task()
 def clear_sent_messages():
